**********************************
**** Non-UN PKO Effectiveness ****
**         STATA v.16           **
**********************************
use non_un_effectiveness_dataset.dta, clear

************************************
*** Table A2. Summary statistics ***
************************************
eststo clear
estpost summarize
esttab using sum.csv, replace cells("count(fmt(0)) mean(fmt(3)) sd(fmt(3)) min(fmt(0)) max(fmt(0))" ) noobs 

************************************
********** Make variables **********
************************************
*	OSV_total
gen dvtotosv=dvgovosv+dvrebosv

*	OSV_dummy
gen osv_dummy=0
replace osv_dummy=1 if dvtotosv>0 & dvtotosv!=.
replace osv_dummy=. if dvtotosv==.

sort conflictid year month

*** Make one lag variables
by conflictid: gen non_un_types1 = non_un_types[_n-1]
by conflictid: gen non_un_types_region1 = non_un_types_region[_n-1]

by conflictid: gen regtroops1 = regtroops_ipo[_n-1]
by conflictid: gen regpolice1 = regpolice_ipo[_n-1]

by conflictid: gen inttroops1 = inttroops_ipo[_n-1]
by conflictid: gen intpolice1 = intpolice_ipo[_n-1]

by conflictid: gen pop1 = pop[_n-1]
by conflictid: gen death_civil1 = deaths_civilians[_n-1]
by conflictid: gen battle_death1 = dvbdeaths[_n-1]
by conflictid: gen osv_dummy_1 = osv_dummy[_n-1]

*** Make control variables
gen nontroops1 = regtroops1 + inttroops1
gen nonpolice1 = regpolice1 + intpolice1

gen lnontroops1=ln(nontroops1+1)
gen lnonpolice1=ln(nonpolice1+1)

gen lregtroops1=ln(regtroops1+1)
gen lregpolice1=ln(regpolice1+1)

gen ldeath_civil1 = ln(death_civil1+1)
gen lbattle_death1 = ln(battle_death1+1)
gen lpop1 = ln(pop1)

gen democracy=0
replace democracy = 1 if polity2 >=6
replace democracy = . if polity2 == .

gen incomp_=0
replace incomp_=1 if incomp==2
drop incomp
rename incomp_ incomp

** pre-deployment variables for matching

sort conflictid year month
by conflictid: gen apre_cas12 = (deaths_civilians[_n-12]+deaths_civilians[_n-7]+deaths_civilians[_n-8]+deaths_civilians[_n-9]+deaths_civilians[_n-10]+deaths_civilians[_n-11] + deaths_civilians[_n-1]+deaths_civilians[_n-2]+deaths_civilians[_n-3]+deaths_civilians[_n-4]+deaths_civilians[_n-5]+deaths_civilians[_n-6])/12
						
by conflictid: gen apre_battle12 = (dvbdeaths[_n-12]+dvbdeaths[_n-7]+dvbdeaths[_n-8]+dvbdeaths[_n-9]+dvbdeaths[_n-10]+dvbdeaths[_n-11] + dvbdeaths[_n-1]+dvbdeaths[_n-2]+dvbdeaths[_n-3]+dvbdeaths[_n-4]+dvbdeaths[_n-5]+dvbdeaths[_n-6])/12

replace apre_cas12 = 0 if apre_cas12 ==.
replace apre_battle12 = 0 if apre_battle12 ==.

gen lapre_cas12 = ln(apre_cas12+1)
gen lapre_battle12 = ln(apre_battle12+1)	

*** distinguish PKOs into four categories
local i = 1
while `i' <=4 {
  gen nontypes_region1`i' = non_un_types_region1==`i'
  local i = `i' + 1
}

local i = 1
while `i' <=4 {
  gen non_un_types1`i' = non_un_types1==`i'
  local i = `i' + 1
}

**** For transition method
*** make time variable
gen s1_t = s1*t
gen s1_t2 = s1*t2

gen s2_t = s2*t
gen s2_t2 = s2*t2


*** S1 and S2

gen s1_lregtroops1 = s1*lregtroops1
gen s1_lregpolice1 = s1*lregpolice1
gen s1_lnontroops1 = s1*lnontroops1
gen s1_lnonpolice1 = s1*lnonpolice1

gen s1_ldeath_civil1 = s1*ldeath_civil1
gen s1_lbattle_death1 = s1*lbattle_death1

gen s1_incomp = s1*incomp
gen s1_lpop1 = s1*lpop1
gen s1_democracy = s1*democracy

gen s1_osv_dummy_1 = s1*osv_dummy_1

gen s2_lregtroops1 = s2*lregtroops1
gen s2_lregpolice1 = s2*lregpolice1
gen s2_lnontroops1 = s2*lnontroops1
gen s2_lnonpolice1 = s2*lnonpolice1

gen s2_ldeath_civil1 = s2*ldeath_civil1
gen s2_lbattle_death1 = s2*lbattle_death1

gen s2_vic_a = s2*victory_a
gen s2_vic_b = s2*victory_b

gen s2_incomp = s2*incomp
gen s2_lpop1 = s2*lpop1
gen s2_democracy = s2*democracy

gen s2_osv_dummy_1 = s2*osv_dummy_1

*********************
** define varibles **
*********************

sort conflictid year month

** set constant and duration variables
global st_1 s1 s1_t s1_t2 
global st_2 s2 s2_t s2_t2 

** set personnel 
global sp_1 s1_luntroops1 s1_lunpolice1 s1_lunobs1 
global sp_2 s2_luntroops1 s2_lunpolice1 s2_lunobs1 

global sp_11 s1_lregtroops1 s1_lregpolice1  
global sp_21 s2_lregtroops1 s2_lregpolice1  

** set control varaibles
global s_1  s1_lbattle_death1 s1_incomp
global s_2  s2_lbattle_death1 s2_incomp

** set peace variables 
global sa_2  s2_vic_a s2_vic_b 

global non_region nontypes_region11 nontypes_region12 nontypes_region13 nontypes_region14
global non non_un_types11 non_un_types12 non_un_types13 non_un_types14
global key   victory_a victory_b lbattle_death1  democracy 
global con   incomp  osv_dummy_1  lpop1 

*********************************
************* Table 1 ***********
*********************************
** matching
** Model 1 in Table A3
psmatch2 regpresence end_dummy lapre_cas12 lapre_battle12  eap eca mena sas lac ssa victory_a victory_b lpop1  , logit noreplacement caliper(0.2) 

** Figure 2
pstest end_dummy lapre_cas12 lapre_battle12  eap eca mena sas lac ssa victory_a victory_b lpop1 , both t(regpresence) graph

** regression
eststo clear

eststo n1: nbreg dvgovosv $non_region $key $con, cl(conflictid)
eststo n2: nbreg dvrebosv $non_region $key $con, cl(conflictid)

eststo n3: nbreg dvgovosv $non_region $key $con [iweight=_weight], cl(conflictid)
eststo n4: nbreg dvrebosv $non_region $key $con [iweight=_weight], cl(conflictid)

estout *, eform cells(b(star fmt(3)) se(par fmt(3))) starlevels(* 0.10 ** 0.05 *** 0.01) stats(N,  fmt(%9.0g %9.3f)) varwidth(20)

*********************************
************* Table 2 ***********
*********************************
** matching
** Model 2 in Table A3
psmatch2 regpresence t t2  end_dummy lapre_cas12 lapre_battle12  eap eca mena sas lac ssa victory_a victory_b lpop1  , logit noreplacement caliper(0.2) 

** Figure A1
pstest  t t2 end_dummy lapre_cas12 lapre_battle12  eap eca mena sas lac ssa victory_a victory_b lpop1 , both t(regpresence) graph

** regression
eststo clear

eststo p1: logit transition $st_1 $sp_11 $s_1 if end_dummy == 0 , nocons cl(conflictid)
eststo p2: logit transition $st_2 $sp_21 $s_2 $sa_2  if end_dummy == 1 , nocons cl(conflictid)

eststo p3: logit transition $st_1 $sp_11 $s_1 [iweight=_weight] if end_dummy == 0 , nocons cl(conflictid)
eststo p4: logit transition $st_2 $sp_21 $s_2 $sa_2 [iweight=_weight] if end_dummy == 1 , nocons cl(conflictid)

estout *, eform cells(b(star fmt(3)) se(par fmt(3))) starlevels(* 0.10 ** 0.05 *** 0.01) stats(N,  fmt(%9.0g %9.3f)) varwidth(20)


*********************************
************* Table 3 ***********
*********************************
** matching
psmatch2 nonunpresence end_dummy lapre_cas12 lapre_battle12  eap eca mena sas lac ssa victory_a victory_b lpop1  , logit noreplacement caliper(0.2) 

pstest end_dummy lapre_cas12 lapre_battle12  eap eca mena sas lac ssa victory_a victory_b lpop1 , both t(nonunpresence) graph

** regression
eststo clear

eststo n1: nbreg dvgovosv $non $key $con, cl(conflictid)
eststo n2: nbreg dvrebosv $non $key $con, cl(conflictid)

eststo n3: nbreg dvgovosv $non $key $con [iweight=_weight], cl(conflictid)
eststo n4: nbreg dvrebosv $non $key $con [iweight=_weight], cl(conflictid)

estout *, eform cells(b(star fmt(3)) se(par fmt(3))) starlevels(* 0.10 ** 0.05 *** 0.01) stats(N,  fmt(%9.0g %9.3f)) varwidth(20)

*********************************
************* Table 4 ***********
*********************************
** matching
psmatch2 nonunpresence t t2  end_dummy lapre_cas12 lapre_battle12  eap eca mena sas lac ssa victory_a victory_b lpop1  , logit noreplacement caliper(0.2) 

pstest  t t2 end_dummy lapre_cas12 lapre_battle12  eap eca mena sas lac ssa victory_a victory_b lpop1 , both t(nonunpresence) graph

global sp_11 s1_lnontroops1 s1_lnonpolice1
global sp_21 s2_lnontroops1 s2_lnonpolice1

** regression
eststo clear

eststo p1: logit transition $st_1 $sp_11 $s_1 if end_dummy == 0 , nocons cl(conflictid)
eststo p2: logit transition $st_2 $sp_21 $s_2 $sa_2  if end_dummy == 1 , nocons cl(conflictid)

eststo p3: logit transition $st_1 $sp_11 $s_1 [iweight=_weight] if end_dummy == 0 , nocons cl(conflictid)
eststo p4: logit transition $st_2 $sp_21 $s_2 $sa_2 [iweight=_weight] if end_dummy == 1 , nocons cl(conflictid)

estout *, eform cells(b(star fmt(3)) se(par fmt(3))) starlevels(* 0.10 ** 0.05 *** 0.01) stats(N,  fmt(%9.0g %9.3f)) varwidth(20)

